class LearningObject::AttachmentBuilder < ::Builder

  ##disable method
  # build attachments with id's is out of scope.
  def self.build(objects = [])
    raise NotImplementedError, 'LearningObject::AttachmentBuilder#build is out of scope.'
  end

  def self.build_from_orientdb(args = {})
    build_from_cache args do
      ::Orientdb::LearningObject::Attachment.new(sanitize_args(args))
    end
  end

  private

  def self.build_from_cache(args={})
    object = nil

    unless args.nil? || !block_given?
      # cache object when build
      object = Rails.cache.fetch(cache_key(args['id'], args['link']), expires_in: 12.hours) { yield }
    end

    object
  end

  def self.sanitize_args(args={})
    args['retrieve_link'] = args.delete('retrieveLink')
    args['mime_type'] = args.delete('mimeType')
    args['size'] = args.delete('sizeBytes')
    args['bundle_name'] = args.delete('bundleName')
    %w(handle type expand parentObject checkSum sequenceId policies).each do |arg|
      args.delete(arg)
    end
    args
  end

end
