class SearchController < ApplicationController
  def index
    @types = LearningObject.default_types

    @subjects = Topic.default_list

    @school_levels = ['Educação Infantil', 'Ensino Fundamental', 'Ensino Médio'].map { |o| Topic.find_by_name(o) }

    @source = Institution.all
  end

  def fetch
    params[:query] = "*" if params[:query].blank?

    @result = LearningObject.search params[:query], where: where_hash(params), order: order_hash(params), page: params[:page] || 1, per_page: 10

    render partial: 'search/fetch'
  end

  def autocomplete
    render json: LearningObject.search(params[:query], {
      fields: ['name^5', 'author'],
      limit: 10,
      load: false,
      misspellings: { below: 5 }
    }).map(&:name)
  end

  private

  def where_hash(params)
    hash = {}

    topics = params[:subject] unless params[:subject].blank?
    topics += ", " unless topics.nil?
    topics = topics.to_s + params[:school_level] unless params[:school_level].blank?

    # build hash
    hash[:topics_name] = topics.split(', ') unless topics.nil?
    hash[:object_type] = params[:type].split(', ') unless params[:type].blank?
    # year = params[:year].blank? ? nil : params[:year].split('-').take(2)

    hash.blank? ? nil : hash
  end

  def order_hash(params)
    case params[:order]
    when 'author'
      { author: :asc }
    when 'publicationasc'
      { published_at: :asc }
    when 'publicationdesc'
      { published_at: :desc }
    when 'title'
      { name: :asc }
    else
      { score: :desc }
    end
  end

end
