class User < ActiveRecord::Base
  include RepositoriesProxy
  include Followable

  # Include default devise modules. Others available are:
  # :confirmable, :lockable, :timeoutable and :omniauthable
  devise :database_authenticatable, :registerable,
         :recoverable, :rememberable, :trackable, :validatable,
         :omniauthable

  has_and_belongs_to_many :roles
  has_and_belongs_to_many :institutions

  has_many :bookmarks, as: :bookmarkable
  has_many :bookmark_collections, through: :bookmarks, source: :bookmarkable, source_type: 'Collection'
  has_many :bookmark_learning_objects, through: :bookmarks, source: :bookmarkable, source_type: 'LearningObject'
  has_many :bookmarks

  has_many :collections, as: :owner

  has_many :learning_objects, as: :publisher

  has_many :views
  has_many :downloads
  has_many :likes
  has_many :shares
  has_many :follows

  after_create :default_role

  has_attached_file :avatar, styles: {medium: "300x300>", thumb: "60x60>"}, default_url: lambda { |image| ActionController::Base.helpers.asset_path('user-anon.png') }
  validates_attachment_content_type :avatar, content_type: /\Aimage\/.*\Z/

  def is_admin?
    roles.each do |role|
      return true if role.name == "admin"
    end
    false
  end

  private

  def default_role
    roles << Role.find_by_name("teacher")
  end

  def self.from_omniauth(access_token)
      data = access_token.info

      if access_token.provider == "twitter"
        user_email = access_token.uid + "@twitter.com"
      else
        user_email = data["email"]
      end

      user = User.where(:email => user_email).first

       unless user
           user = User.create(name: data["name"],
                              email: user_email,
                              provider: access_token.provider,
                              uid: access_token.uid,
                              password: Devise.friendly_token[0,20]
                              )
       end
      user
  end

end
