class ScoreCalculatorWorker
  include Sidekiq::Worker
  sidekiq_options queue: :score
  include RepositoriesProxy

  def perform(rid)
    object = LearningObject.find(rid)

    unless object.blank?
        # Weights to score. Sum must be 1000
        weights = {
            "thumbnail": 250,
            "description": 150,
            "likes": 250,
            "views": 150,
            "downloads":200
          }

    score = 0

    # 250 points if it has thumbnail
    score += weights[:thumbnail] unless object.thumbnail.blank?

    # 150 points if it has description
    score += weights[:description] unless object.description.blank?

    # range to 250 points, for normalized likes ( maxLikes/actualLike => [0..1] )
    score += divide_by_max(
                            LearningObject.count('Likes', object),
                            LearningObject.max('Likes'),
                            weights[:likes]
                          )

    # range to 200 points, for normalized views ( maxLikes/actualLike => [0..1] )
    score += divide_by_max(
                            LearningObject.count('Views', object),
                            LearningObject.max('Views'),
                            weights[:views]
                          )

    # downloads
    score += divide_by_max(
                            LearningObject.count('Downloads', object),
                            LearningObject.max('Downloads'),
                            weights[:downloads]
                          )

    LearningObject.update_property(object, 'score', score)
    end
  end

  private

  def divide_by_max(i, max, weight)
    if (i > 0 && max > 0) && (i <= max)
      (i / max) * weight
    else
      0
    end
  end
end
